@@ -26,11 +26,16 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
         except:
             pass
         for item in self.flow_manager.run(flow_name, content, attributes):
-            yield FlowExecuteResponse(
-                attributes=json.dumps(item.attributes, default=grebble_converter),
-                content=json.dumps(item.content, default=grebble_converter),
+            content = json.dumps(item.content, default=grebble_converter)
+            resp = FlowExecuteResponse(
+                content=content.encode(),
                 streamEnd=False,
+                mimeType="text/plain",
+                commit=True,
             )
+            resp.attributes.update(item.attributes)
+
+            yield resp
 
         yield FlowExecuteResponse(
             content=None, attributes=None, streamEnd=True
